/*
This program loads the common component from each of the bootstrap 
samples back into Stata and performs the Gelbach decomposition on 
each bootstrap sample. The 5% and 95% percentiles of the decomposition 
components across the bootstrap samples are used to construct the CIs 
for the decomposotion estimates reported in the paper.
*/


global mydatapath "../mydata"
global outputpath "../output"


log using ./decomposition_CIs_minti15.log, replace

clear
clear matrix
clear mata
set maxvar 11000


*** 1. LOOP THROUGH BOOTSTRAP DATASETS AND COMPUTE DECOMPOSITION COMPONENTS ***
postfile bsresults str13 estimator str30 component str8 model brep bias using ${mydatapath}/bsresults.dta, replace



local sample insample_minti15
local models woD wD

foreach m of local models {

if "`m'"=="woD" {
	local spec Education Education2 Age Age2 EducAge
}
if "`m'"=="wD" {
	local spec Education Education2 Age Age2 EducAge c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year
}


forvalues brep=1/400 {
	
	
***** IFE *****
* PCA PROXY VERSION
* FIRST, MERGE COMMON COMPONENT FROM MATLAB BACK INTO STATA
*import common component
import delimited "../mydata/common_bs_ife_`m'wP.csv", varnames(nonames) encoding(Big5) clear 
local v1=1+(`brep'-1)*25
local v2=25+(`brep'-1)*25
keep v`v1'-v`v2'
rename v* v#, renumber(1)
rename v* common*
save ${mydatapath}/common_bs`brep'_ife_`m'wP.dta, replace

*get the caseid_1979 list the corresponds to the common component
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep log_HourlyWage1_cpi year caseid_1979
reshape wide log_HourlyWage1_cpi, i(caseid_1979) j(year)
keep caseid_1979
save ${mydatapath}/caseid_1979_list.dta, replace


*merge the common component onto ID list
merge 1:1 _n using ${mydatapath}/common_bs`brep'_ife_`m'wP.dta
drop _merge
reshape long common, i(caseid_1979) j(year)
replace year=year+1980
replace year=year+1*(year-1994) if year>1994
save ${mydatapath}/common_bs`brep'_ife_`m'wP_matched.dta, replace

*finally, merge common component back to the full doa
use ${mydatapath}/NLSYrep_doa.dta, clear
merge 1:1 caseid_1979 year using ${mydatapath}/common_bs`brep'_ife_`m'wP_matched.dta, gen(_mergeCommon)



* RUN REGRESSIONS
* PCA proxies version
drop factor_c factor_n1 factor_n2 factor_n3
rename (factor_c_minti15 factor_n1_minti15 factor_n2_minti15 factor_n3_minti15) (factor_c factor_n1 factor_n2 factor_n3)

gen Y_defac=log_HourlyWage1_cpi-common

sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


*no proxies, no demos
xtreg log_HourlyWage1_cpi `spec' if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local ols=r(estimate)

*full model
xtreg Y_defac `spec' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local full=r(estimate)

local total_bias=`ols'-`full'
post bsresults ("IFE - PCA") ("total") ("`model'") (`brep') (`total_bias')

gen proxy_comp_total=.
forvalues y=1981/1994 {
	replace proxy_comp_total=_b[`y'.year#c.factor_c]*factor_c +_b[`y'.year#c.factor_n1]*factor_n1 +_b[`y'.year#c.factor_n2]*factor_n2 +_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_total=_b[`y'.year#c.factor_c]*factor_c +_b[`y'.year#c.factor_n1]*factor_n1 +_b[`y'.year#c.factor_n2]*factor_n2 +_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}

gen proxy_comp_c=.
forvalues y=1981/1994 {
	replace proxy_comp_c=_b[`y'.year#c.factor_c]*factor_c if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_c=_b[`y'.year#c.factor_c]*factor_c if year==`y' & `sample'==1
}

gen proxy_comp_n1=.
forvalues y=1981/1994 {
	replace proxy_comp_n1=_b[`y'.year#c.factor_n1]*factor_n1 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n1=_b[`y'.year#c.factor_n1]*factor_n1 if year==`y' & `sample'==1
}

gen proxy_comp_n2=.
forvalues y=1981/1994 {
	replace proxy_comp_n2=_b[`y'.year#c.factor_n2]*factor_n2 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n2=_b[`y'.year#c.factor_n2]*factor_n2 if year==`y' & `sample'==1
}

gen proxy_comp_n3=.
forvalues y=1981/1994 {
	replace proxy_comp_n3=_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n3=_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}


sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


xtreg common `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - PCA") ("loadings") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_total `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - PCA") ("proxies all") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_c `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - PCA") ("cog") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_n1 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - PCA") ("noncog1") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_n2 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - PCA") ("noncog2") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_n3 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - PCA") ("noncog3") ("`model'") (`brep') (r(estimate))
	
	
	

	
	
	
* non-PCA PROXY VERSION
* FIRST, MERGE COMMON COMPONENT FROM MATLAB BACK INTO STATA
*import common component
import delimited "../mydata/common_bs_ife_`m'wPalt.csv", varnames(nonames) encoding(Big5) clear 
local v1=1+(`brep'-1)*25
local v2=25+(`brep'-1)*25
keep v`v1'-v`v2'
rename v* v#, renumber(1)
rename v* common*
save ${mydatapath}/common_bs`brep'_ife_`m'wPalt.dta, replace

*get the caseid_1979 list the corresponds to the common component
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep log_HourlyWage1_cpi year caseid_1979
reshape wide log_HourlyWage1_cpi, i(caseid_1979) j(year)
keep caseid_1979
save ${mydatapath}/caseid_1979_list.dta, replace

*merge the common component onto ID list
merge 1:1 _n using ${mydatapath}/common_bs`brep'_ife_`m'wPalt.dta
drop _merge
reshape long common, i(caseid_1979) j(year)
replace year=year+1980
replace year=year+1*(year-1994) if year>1994
save ${mydatapath}/common_bs`brep'_ife_`m'wPalt_matched.dta, replace


*finally, merge common component back to the full doa
use ${mydatapath}/NLSYrep_doa.dta, clear
merge 1:1 caseid_1979 year using ${mydatapath}/common_bs`brep'_ife_`m'wPalt_matched.dta, gen(_mergeCommon)



* RUN REGRESSIONS
* PCA proxies version
gen Y_defac=log_HourlyWage1_cpi-common

sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


*no proxies, no demos
xtreg log_HourlyWage1_cpi `spec' if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local ols=r(estimate)

*full model
xtreg Y_defac `spec' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local full=r(estimate)

local total_bias=`ols'-`full'
post bsresults ("IFE - nonPCA") ("total") ("`model'") (`brep') (`total_bias')

gen proxy_comp_total=.
forvalues y=1981/1994 {
	replace proxy_comp_total=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std + _b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std + _b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std + _b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std + _b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std + _b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std + _b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std + _b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std + _b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std + _b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std + _b[`y'.year#c.rott_std]*rott_std + _b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_total=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std + _b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std + _b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std + _b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std + _b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std + _b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std + _b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std + _b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std + _b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std + _b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std + _b[`y'.year#c.rott_std]*rott_std + _b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab3=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab3=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab3=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab4=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab4=_b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab4=_b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab5=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab5=_b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab5=_b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab6=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab6=_b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab6=_b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab7=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab7=_b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab7=_b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab8=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab8=_b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab8=_b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab9=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab9=_b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab9=_b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab10=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab10=_b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab10=_b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab11=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab11=_b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab11=_b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab12=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab12=_b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab12=_b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_rott=.
forvalues y=1981/1994 {
	replace proxy_comp_rott=_b[`y'.year#c.rott_std]*rott_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_rott=_b[`y'.year#c.rott_std]*rott_std if year==`y' & `sample'==1
}
gen proxy_comp_rosen=.
forvalues y=1981/1994 {
	replace proxy_comp_rosen=_b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_rosen=_b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}



sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)

xtreg common `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - nonPCA") ("loadings") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_total `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - nonPCA") ("proxies all") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab3 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - nonPCA") ("general science") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab4 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - nonPCA") ("arithmetic reasoning") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab10 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - nonPCA") ("mathematical knowledge") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab6 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - nonPCA") ("paragraph comprehension") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab5 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - nonPCA") ("word knowledge") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab8 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - nonPCA") ("coding speed") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab7 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - nonPCA") ("numeric operations") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab9 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - nonPCA") ("auto and shop information") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab12 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - nonPCA") ("electronic information") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab11 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - nonPCA") ("mechanical comprehension") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_rott `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - nonPCA") ("rott") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_rosen `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("IFE - nonPCA") ("rosen") ("`model'") (`brep') (r(estimate))

	





***** CCE *****
* PCA PROXY VERSION
* FIRST, MERGE COMMON COMPONENT FROM MATLAB BACK INTO STATA
*import common component
import delimited "../mydata/common_bs_cce_`m'wP.csv", varnames(nonames) encoding(Big5) clear 
local v1=1+(`brep'-1)*25
local v2=25+(`brep'-1)*25
keep v`v1'-v`v2'
rename v* v#, renumber(1)
rename v* common*
save ${mydatapath}/common_bs`brep'_cce_`m'wP.dta, replace

*get the caseid_1979 list the corresponds to the common component
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep log_HourlyWage1_cpi year caseid_1979
reshape wide log_HourlyWage1_cpi, i(caseid_1979) j(year)
keep caseid_1979
save ${mydatapath}/caseid_1979_list.dta, replace

*merge the common component onto ID list
merge 1:1 _n using ${mydatapath}/common_bs`brep'_cce_`m'wP.dta
drop _merge
reshape long common, i(caseid_1979) j(year)
replace year=year+1980
replace year=year+1*(year-1994) if year>1994
save ${mydatapath}/common_bs`brep'_cce_`m'wP_matched.dta, replace

*finally, merge common component back to the full doa
use ${mydatapath}/NLSYrep_doa.dta, clear
merge 1:1 caseid_1979 year using ${mydatapath}/common_bs`brep'_cce_`m'wP_matched.dta, gen(_mergeCommon)



* RUN REGRESSIONS
* PCA proxies version
drop factor_c factor_n1 factor_n2 factor_n3
rename (factor_c_minti15 factor_n1_minti15 factor_n2_minti15 factor_n3_minti15) (factor_c factor_n1 factor_n2 factor_n3)

gen Y_defac=log_HourlyWage1_cpi-common

sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


*no proxies, no demos
xtreg log_HourlyWage1_cpi `spec' if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local ols=r(estimate)

*full model
xtreg Y_defac `spec' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local full=r(estimate)

local total_bias=`ols'-`full'
post bsresults ("CCE - PCA") ("total") ("`model'") (`brep') (`total_bias')

gen proxy_comp_total=.
forvalues y=1981/1994 {
	replace proxy_comp_total=_b[`y'.year#c.factor_c]*factor_c +_b[`y'.year#c.factor_n1]*factor_n1 +_b[`y'.year#c.factor_n2]*factor_n2 +_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_total=_b[`y'.year#c.factor_c]*factor_c +_b[`y'.year#c.factor_n1]*factor_n1 +_b[`y'.year#c.factor_n2]*factor_n2 +_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}

gen proxy_comp_c=.
forvalues y=1981/1994 {
	replace proxy_comp_c=_b[`y'.year#c.factor_c]*factor_c if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_c=_b[`y'.year#c.factor_c]*factor_c if year==`y' & `sample'==1
}

gen proxy_comp_n1=.
forvalues y=1981/1994 {
	replace proxy_comp_n1=_b[`y'.year#c.factor_n1]*factor_n1 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n1=_b[`y'.year#c.factor_n1]*factor_n1 if year==`y' & `sample'==1
}

gen proxy_comp_n2=.
forvalues y=1981/1994 {
	replace proxy_comp_n2=_b[`y'.year#c.factor_n2]*factor_n2 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n2=_b[`y'.year#c.factor_n2]*factor_n2 if year==`y' & `sample'==1
}

gen proxy_comp_n3=.
forvalues y=1981/1994 {
	replace proxy_comp_n3=_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n3=_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}



sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


xtreg common `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - PCA") ("loadings")  ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_total `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - PCA") ("proxies total") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_c `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - PCA") ("cog") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_n1 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - PCA") ("noncog1") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_n2 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - PCA") ("noncog2") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_n3 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - PCA") ("noncog3") ("`model'") (`brep') (r(estimate))

	
	

	
	
	
	
* non-PCA PROXY VERSION
* FIRST, MERGE COMMON COMPONENT FROM MATLAB BACK INTO STATA
*import common component
import delimited "../mydata/common_bs_cce_`m'wPalt.csv", varnames(nonames) encoding(Big5) clear 
local v1=1+(`brep'-1)*25
local v2=25+(`brep'-1)*25
keep v`v1'-v`v2'
rename v* v#, renumber(1)
rename v* common*
save ${mydatapath}/common_bs`brep'_cce_`m'wPalt.dta, replace

*get the caseid_1979 list the corresponds to the common component
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep log_HourlyWage1_cpi year caseid_1979
reshape wide log_HourlyWage1_cpi, i(caseid_1979) j(year)
keep caseid_1979
save ${mydatapath}/caseid_1979_list.dta, replace

*merge the common component onto ID list
merge 1:1 _n using ${mydatapath}/common_bs`brep'_cce_`m'wPalt.dta
drop _merge
reshape long common, i(caseid_1979) j(year)
replace year=year+1980
replace year=year+1*(year-1994) if year>1994
save ${mydatapath}/common_bs`brep'_cce_`m'wPalt_matched.dta, replace

*finally, merge common component back to the full doa
use ${mydatapath}/NLSYrep_doa.dta, clear
merge 1:1 caseid_1979 year using ${mydatapath}/common_bs`brep'_cce_`m'wPalt_matched.dta, gen(_mergeCommon)



* RUN REGRESSIONS
* PCA proxies version
gen Y_defac=log_HourlyWage1_cpi-common

sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


*no proxies, no demos
xtreg log_HourlyWage1_cpi `spec' if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local ols=r(estimate)

*full model
xtreg Y_defac `spec' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local full=r(estimate)

local total_bias=`ols'-`full'
post bsresults ("CCE - nonPCA") ("total") ("`model'") (`brep') (`total_bias')

gen proxy_comp_total=.
forvalues y=1981/1994 {
	replace proxy_comp_total=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std + _b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std + _b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std + _b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std + _b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std + _b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std + _b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std + _b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std + _b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std + _b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std + _b[`y'.year#c.rott_std]*rott_std + _b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_total=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std + _b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std + _b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std + _b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std + _b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std + _b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std + _b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std + _b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std + _b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std + _b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std + _b[`y'.year#c.rott_std]*rott_std + _b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab3=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab3=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab3=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab4=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab4=_b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab4=_b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab5=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab5=_b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab5=_b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab6=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab6=_b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab6=_b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab7=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab7=_b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab7=_b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab8=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab8=_b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab8=_b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab9=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab9=_b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab9=_b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab10=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab10=_b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab10=_b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab11=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab11=_b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab11=_b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab12=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab12=_b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab12=_b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_rott=.
forvalues y=1981/1994 {
	replace proxy_comp_rott=_b[`y'.year#c.rott_std]*rott_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_rott=_b[`y'.year#c.rott_std]*rott_std if year==`y' & `sample'==1
}
gen proxy_comp_rosen=.
forvalues y=1981/1994 {
	replace proxy_comp_rosen=_b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_rosen=_b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}



sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)

xtreg common `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - nonPCA") ("loadings") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_total `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - nonPCA") ("proxies total") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab3 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - nonPCA") ("general science") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab4 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - nonPCA") ("arithmetic reasoning") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab10 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - nonPCA") ("mathematical knowledge") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab6 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - nonPCA") ("paragraph comprehension") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab5 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - nonPCA") ("word knowledge") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab8 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - nonPCA") ("coding speed") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab7 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - nonPCA") ("numeric operations") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab9 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - nonPCA") ("auto and shop information") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab12 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - nonPCA") ("electronic information") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab11 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - nonPCA") ("mechanical comprehension") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_rott `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - nonPCA") ("rott") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_rosen `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE - nonPCA") ("rosen") ("`model'") (`brep') (r(estimate))






***** CCE2 *****
* PCA PROXY VERSION
* FIRST, MERGE COMMON COMPONENT FROM MATLAB BACK INTO STATA
*import common component
import delimited "../mydata/common_bs_cce2_`m'wP.csv", varnames(nonames) encoding(Big5) clear 
local v1=1+(`brep'-1)*25
local v2=25+(`brep'-1)*25
keep v`v1'-v`v2'
rename v* v#, renumber(1)
rename v* common*
save ${mydatapath}/common_bs`brep'_cce2_`m'wP.dta, replace

*get the caseid_1979 list the corresponds to the common component
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep log_HourlyWage1_cpi year caseid_1979
reshape wide log_HourlyWage1_cpi, i(caseid_1979) j(year)
keep caseid_1979
save ${mydatapath}/caseid_1979_list.dta, replace

*merge the common component onto ID list
merge 1:1 _n using ${mydatapath}/common_bs`brep'_cce2_`m'wP.dta
drop _merge
reshape long common, i(caseid_1979) j(year)
replace year=year+1980
replace year=year+1*(year-1994) if year>1994
save ${mydatapath}/common_bs`brep'_cce2_`m'wP_matched.dta, replace

*finally, merge common component back to the full doa
use ${mydatapath}/NLSYrep_doa.dta, clear
merge 1:1 caseid_1979 year using ${mydatapath}/common_bs`brep'_cce2_`m'wP_matched.dta, gen(_mergeCommon)



* RUN REGRESSIONS
* PCA proxies version
drop factor_c factor_n1 factor_n2 factor_n3
rename (factor_c_minti15 factor_n1_minti15 factor_n2_minti15 factor_n3_minti15) (factor_c factor_n1 factor_n2 factor_n3)

gen Y_defac=log_HourlyWage1_cpi-common

sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)



*no proxies, no demos
xtreg log_HourlyWage1_cpi `spec' if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local ols=r(estimate)

*full model
xtreg Y_defac `spec' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local full=r(estimate)

local total_bias=`ols'-`full'
post bsresults ("CCE2 - PCA") ("total") ("`model'") (`brep') (`total_bias')

gen proxy_comp_total=.
forvalues y=1981/1994 {
	replace proxy_comp_total=_b[`y'.year#c.factor_c]*factor_c +_b[`y'.year#c.factor_n1]*factor_n1 +_b[`y'.year#c.factor_n2]*factor_n2 +_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_total=_b[`y'.year#c.factor_c]*factor_c +_b[`y'.year#c.factor_n1]*factor_n1 +_b[`y'.year#c.factor_n2]*factor_n2 +_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}

gen proxy_comp_c=.
forvalues y=1981/1994 {
	replace proxy_comp_c=_b[`y'.year#c.factor_c]*factor_c if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_c=_b[`y'.year#c.factor_c]*factor_c if year==`y' & `sample'==1
}

gen proxy_comp_n1=.
forvalues y=1981/1994 {
	replace proxy_comp_n1=_b[`y'.year#c.factor_n1]*factor_n1 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n1=_b[`y'.year#c.factor_n1]*factor_n1 if year==`y' & `sample'==1
}

gen proxy_comp_n2=.
forvalues y=1981/1994 {
	replace proxy_comp_n2=_b[`y'.year#c.factor_n2]*factor_n2 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n2=_b[`y'.year#c.factor_n2]*factor_n2 if year==`y' & `sample'==1
}

gen proxy_comp_n3=.
forvalues y=1981/1994 {
	replace proxy_comp_n3=_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n3=_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}



sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


xtreg common `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - PCA") ("loadings") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_total `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - PCA") ("proxies total") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_c `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - PCA") ("cog") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_n1 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - PCA") ("noncog1") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_n2 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - PCA") ("noncog2") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_n3 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - PCA") ("noncog3") ("`model'") (`brep') (r(estimate))

	
	

	
	
		
* non-PCA PROXY VERSION
* FIRST, MERGE COMMON COMPONENT FROM MATLAB BACK INTO STATA
*import common component
import delimited "../mydata/common_bs_cce2_`m'wPalt.csv", varnames(nonames) encoding(Big5) clear 
local v1=1+(`brep'-1)*25
local v2=25+(`brep'-1)*25
keep v`v1'-v`v2'
rename v* v#, renumber(1)
rename v* common*
save ${mydatapath}/common_bs`brep'_cce2_`m'wPalt.dta, replace

*get the caseid_1979 list the corresponds to the common component
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep log_HourlyWage1_cpi year caseid_1979
reshape wide log_HourlyWage1_cpi, i(caseid_1979) j(year)
keep caseid_1979
save ${mydatapath}/caseid_1979_list.dta, replace

*merge the common component onto ID list
merge 1:1 _n using ${mydatapath}/common_bs`brep'_cce2_`m'wPalt.dta
drop _merge
reshape long common, i(caseid_1979) j(year)
replace year=year+1980
replace year=year+1*(year-1994) if year>1994
save ${mydatapath}/common_bs`brep'_cce2_`m'wPalt_matched.dta, replace

*finally, merge common component back to the full doa
use ${mydatapath}/NLSYrep_doa.dta, clear
merge 1:1 caseid_1979 year using ${mydatapath}/common_bs`brep'_cce2_`m'wPalt_matched.dta, gen(_mergeCommon)



* RUN REGRESSIONS
* PCA proxies version
gen Y_defac=log_HourlyWage1_cpi-common

sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


*no proxies, no demos
xtreg log_HourlyWage1_cpi `spec' if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local ols=r(estimate)

*full model
xtreg Y_defac `spec' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local full=r(estimate)

local total_bias=`ols'-`full'
post bsresults ("CCE2 - nonPCA") ("total") ("`model'") (`brep') (`total_bias')

gen proxy_comp_total=.
forvalues y=1981/1994 {
	replace proxy_comp_total=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std + _b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std + _b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std + _b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std + _b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std + _b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std + _b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std + _b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std + _b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std + _b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std + _b[`y'.year#c.rott_std]*rott_std + _b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_total=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std + _b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std + _b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std + _b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std + _b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std + _b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std + _b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std + _b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std + _b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std + _b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std + _b[`y'.year#c.rott_std]*rott_std + _b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab3=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab3=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab3=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab4=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab4=_b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab4=_b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab5=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab5=_b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab5=_b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab6=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab6=_b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab6=_b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab7=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab7=_b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab7=_b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab8=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab8=_b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab8=_b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab9=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab9=_b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab9=_b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab10=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab10=_b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab10=_b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab11=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab11=_b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab11=_b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab12=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab12=_b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab12=_b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_rott=.
forvalues y=1981/1994 {
	replace proxy_comp_rott=_b[`y'.year#c.rott_std]*rott_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_rott=_b[`y'.year#c.rott_std]*rott_std if year==`y' & `sample'==1
}
gen proxy_comp_rosen=.
forvalues y=1981/1994 {
	replace proxy_comp_rosen=_b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_rosen=_b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}



sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)

xtreg common `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - nonPCA") ("loadings") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_total `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - nonPCA") ("proxies total")  ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab3 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - nonPCA") ("general science") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab4 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - nonPCA") ("arithmetic reasoning") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab10 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - nonPCA") ("mathematical knowledge") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab6 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - nonPCA") ("paragraph comprehension") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab5 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - nonPCA") ("word knowledge") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab8 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - nonPCA") ("coding speed") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab7 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - nonPCA") ("numeric operations") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab9 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - nonPCA") ("auto and shop information") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab12 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - nonPCA") ("electronic information") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_asvab11 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - nonPCA") ("mechanical comprehension")  ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_rott `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - nonPCA") ("rott") ("`model'") (`brep') (r(estimate))

xtreg proxy_comp_rosen `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
post bsresults ("CCE2 - nonPCA") ("rosen") ("`model'") (`brep') (r(estimate))


}
}

postclose bsresults




*** 2. COMPUTE STANDARD DEVIATION OF DECOMPOSITION COMPONENTS ACROSS BOOTSTRAP DATASETS ***
use ${mydatapath}/bsresults.dta, clear

replace model="woD" if _n<=26400
replace model="wD" if _n>26400


collapse (sd) se=bias, by(estimator component model)



local models woD wD

foreach m of local models {
putexcel set ../output/dtable_`m'_minti15.xlsx, sheet(table) modify

*** IFE 
*
sum se if estimator=="IFE - PCA" & component=="total" & model=="`m'"
local selocal=r(mean)
putexcel B5=`selocal'

sum se if estimator=="IFE - PCA" & component=="loadings" & model=="`m'"
local selocal=r(mean)
putexcel B7=`selocal'

sum se if estimator=="IFE - PCA" & component=="proxies all" & model=="`m'"
local selocal=r(mean)
putexcel B9=`selocal'

sum se if estimator=="IFE - PCA" & component=="cog" & model=="`m'"
local selocal=r(mean)
putexcel B11=`selocal'

sum se if estimator=="IFE - PCA" & component=="noncog1" & model=="`m'"
local selocal=r(mean)
putexcel B13=`selocal'

sum se if estimator=="IFE - PCA" & component=="noncog2" & model=="`m'"
local selocal=r(mean)
putexcel B15=`selocal'

sum se if estimator=="IFE - PCA" & component=="noncog3" & model=="`m'"
local selocal=r(mean)
putexcel B17=`selocal'

*
sum se if estimator=="IFE - nonPCA" & component=="total" & model=="`m'"
local selocal=r(mean)
putexcel C5=`selocal'

sum se if estimator=="IFE - nonPCA" & component=="loadings" & model=="`m'"
local selocal=r(mean)
putexcel C7=`selocal'

sum se if estimator=="IFE - nonPCA" & component=="proxies all" & model=="`m'"
local selocal=r(mean)
putexcel C9=`selocal'

sum se if estimator=="IFE - nonPCA" & component=="general science" & model=="`m'"
local selocal=r(mean)
putexcel C19=`selocal'

sum se if estimator=="IFE - nonPCA" & component=="arithmetic reasoning" & model=="`m'"
local selocal=r(mean)
putexcel C21=`selocal'

sum se if estimator=="IFE - nonPCA" & component=="mathematical knowledge" & model=="`m'"
local selocal=r(mean)
putexcel C23=`selocal'

sum se if estimator=="IFE - nonPCA" & component=="paragraph comprehension" & model=="`m'"
local selocal=r(mean)
putexcel C25=`selocal'

sum se if estimator=="IFE - nonPCA" & component=="word knowledge" & model=="`m'"
local selocal=r(mean)
putexcel C27=`selocal'

sum se if estimator=="IFE - nonPCA" & component=="coding speed" & model=="`m'"
local selocal=r(mean)
putexcel C29=`selocal'

sum se if estimator=="IFE - nonPCA" & component=="numeric operations" & model=="`m'"
local selocal=r(mean)
putexcel C31=`selocal'

sum se if estimator=="IFE - nonPCA" & component=="auto and shop information" & model=="`m'"
local selocal=r(mean)
putexcel C33=`selocal'

sum se if estimator=="IFE - nonPCA" & component=="electronic information" & model=="`m'"
local selocal=r(mean)
putexcel C35=`selocal'

sum se if estimator=="IFE - nonPCA" & component=="mechanical comprehension" & model=="`m'"
local selocal=r(mean)
putexcel C37=`selocal'

sum se if estimator=="IFE - nonPCA" & component=="rott" & model=="`m'"
local selocal=r(mean)
putexcel C39=`selocal'

sum se if estimator=="IFE - nonPCA" & component=="rosen" & model=="`m'"
local selocal=r(mean)
putexcel C41=`selocal'


*** CCE
*
sum se if estimator=="CCE - PCA" & component=="total" & model=="`m'"
local selocal=r(mean)
putexcel D5=`selocal'

sum se if estimator=="CCE - PCA" & component=="loadings" & model=="`m'"
local selocal=r(mean)
putexcel D7=`selocal'

sum se if estimator=="CCE - PCA" & component=="proxies total" & model=="`m'"
local selocal=r(mean)
putexcel D9=`selocal'

sum se if estimator=="CCE - PCA" & component=="cog" & model=="`m'"
local selocal=r(mean)
putexcel D11=`selocal'

sum se if estimator=="CCE - PCA" & component=="noncog1" & model=="`m'"
local selocal=r(mean)
putexcel D13=`selocal'

sum se if estimator=="CCE - PCA" & component=="noncog2" & model=="`m'"
local selocal=r(mean)
putexcel D15=`selocal'

sum se if estimator=="CCE - PCA" & component=="noncog3" & model=="`m'"
local selocal=r(mean)
putexcel D17=`selocal'

*
sum se if estimator=="CCE - nonPCA" & component=="total" & model=="`m'"
local selocal=r(mean)
putexcel E5=`selocal'

sum se if estimator=="CCE - nonPCA" & component=="loadings" & model=="`m'"
local selocal=r(mean)
putexcel E7=`selocal'

sum se if estimator=="CCE - nonPCA" & component=="proxies total" & model=="`m'"
local selocal=r(mean)
putexcel E9=`selocal'

sum se if estimator=="CCE - nonPCA" & component=="general science" & model=="`m'"
local selocal=r(mean)
putexcel E19=`selocal'

sum se if estimator=="CCE - nonPCA" & component=="arithmetic reasoning" & model=="`m'"
local selocal=r(mean)
putexcel E21=`selocal'

sum se if estimator=="CCE - nonPCA" & component=="mathematical knowledge" & model=="`m'"
local selocal=r(mean)
putexcel E23=`selocal'

sum se if estimator=="CCE - nonPCA" & component=="paragraph comprehension" & model=="`m'"
local selocal=r(mean)
putexcel E25=`selocal'

sum se if estimator=="CCE - nonPCA" & component=="word knowledge" & model=="`m'"
local selocal=r(mean)
putexcel E27=`selocal'

sum se if estimator=="CCE - nonPCA" & component=="coding speed" & model=="`m'"
local selocal=r(mean)
putexcel E29=`selocal'

sum se if estimator=="CCE - nonPCA" & component=="numeric operations" & model=="`m'"
local selocal=r(mean)
putexcel E31=`selocal'

sum se if estimator=="CCE - nonPCA" & component=="auto and shop information" & model=="`m'"
local selocal=r(mean)
putexcel E33=`selocal'

sum se if estimator=="CCE - nonPCA" & component=="electronic information" & model=="`m'"
local selocal=r(mean)
putexcel E35=`selocal'

sum se if estimator=="CCE - nonPCA" & component=="mechanical comprehension" & model=="`m'"
local selocal=r(mean)
putexcel E37=`selocal'

sum se if estimator=="CCE - nonPCA" & component=="rott" & model=="`m'"
local selocal=r(mean)
putexcel E39=`selocal'

sum se if estimator=="CCE - nonPCA" & component=="rosen" & model=="`m'"
local selocal=r(mean)
putexcel E41=`selocal'


*** CCE2
*
sum se if estimator=="CCE2 - PCA" & component=="total" & model=="`m'"
local selocal=r(mean)
putexcel F5=`selocal'

sum se if estimator=="CCE2 - PCA" & component=="loadings" & model=="`m'"
local selocal=r(mean)
putexcel F7=`selocal'

sum se if estimator=="CCE2 - PCA" & component=="proxies total" & model=="`m'"
local selocal=r(mean)
putexcel F9=`selocal'

sum se if estimator=="CCE2 - PCA" & component=="cog" & model=="`m'"
local selocal=r(mean)
putexcel F11=`selocal'

sum se if estimator=="CCE2 - PCA" & component=="noncog1" & model=="`m'"
local selocal=r(mean)
putexcel F13=`selocal'

sum se if estimator=="CCE2 - PCA" & component=="noncog2" & model=="`m'"
local selocal=r(mean)
putexcel F15=`selocal'

sum se if estimator=="CCE2 - PCA" & component=="noncog3" & model=="`m'"
local selocal=r(mean)
putexcel F17=`selocal'

*
sum se if estimator=="CCE2 - nonPCA" & component=="total" & model=="`m'"
local selocal=r(mean)
putexcel G5=`selocal'

sum se if estimator=="CCE2 - nonPCA" & component=="loadings" & model=="`m'"
local selocal=r(mean)
putexcel G7=`selocal'

sum se if estimator=="CCE2 - nonPCA" & component=="proxies total" & model=="`m'"
local selocal=r(mean)
putexcel G9=`selocal'

sum se if estimator=="CCE2 - nonPCA" & component=="general science" & model=="`m'"
local selocal=r(mean)
putexcel G19=`selocal'

sum se if estimator=="CCE2 - nonPCA" & component=="arithmetic reasoning" & model=="`m'"
local selocal=r(mean)
putexcel G21=`selocal'

sum se if estimator=="CCE2 - nonPCA" & component=="mathematical knowledge" & model=="`m'"
local selocal=r(mean)
putexcel G23=`selocal'

sum se if estimator=="CCE2 - nonPCA" & component=="paragraph comprehension" & model=="`m'"
local selocal=r(mean)
putexcel G25=`selocal'

sum se if estimator=="CCE2 - nonPCA" & component=="word knowledge" & model=="`m'"
local selocal=r(mean)
putexcel G27=`selocal'

sum se if estimator=="CCE2 - nonPCA" & component=="coding speed" & model=="`m'"
local selocal=r(mean)
putexcel G29=`selocal'

sum se if estimator=="CCE2 - nonPCA" & component=="numeric operations" & model=="`m'"
local selocal=r(mean)
putexcel G31=`selocal'

sum se if estimator=="CCE2 - nonPCA" & component=="auto and shop information" & model=="`m'"
local selocal=r(mean)
putexcel G33=`selocal'

sum se if estimator=="CCE2 - nonPCA" & component=="electronic information" & model=="`m'"
local selocal=r(mean)
putexcel G35=`selocal'

sum se if estimator=="CCE2 - nonPCA" & component=="mechanical comprehension" & model=="`m'"
local selocal=r(mean)
putexcel G37=`selocal'

sum se if estimator=="CCE2 - nonPCA" & component=="rott" & model=="`m'"
local selocal=r(mean)
putexcel G39=`selocal'

sum se if estimator=="CCE2 - nonPCA" & component=="rosen" & model=="`m'"
local selocal=r(mean)
putexcel G41=`selocal'




}

log close

