/*
This program loads the common component from the factor model 
regressions back into Stata and re-estimates the full model given 
the common component in order to recover the proper delta_t 
coefficients for the proxies (proxy-by-year FEs were projected 
out before sending the data into Matlab to get the FM estimates).

Then, the common component and the proxy-by-year coefs are used 
to obtain the Gelbach decomposition results
*/


global mydatapath "../mydata"
global outputpath "../output"

log using ./decomposition_minti15.log, replace

local sample insample_minti15
local models woD wD

foreach m of local models {

if "`m'"=="woD" {
	local spec Education Education2 Age Age2 EducAge
}
if "`m'"=="wD" {
	local spec Education Education2 Age Age2 EducAge c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year
}

putexcel set ../output/dtable_`m'_minti15.xlsx, sheet(table) replace
putexcel A1:G1, border(bottom)
putexcel B2:C2, merge hcenter
putexcel D2:E2, merge hcenter
putexcel F2:G2, merge hcenter
putexcel B2="IFE"
putexcel D2="CCE"
putexcel F2="CCE2"
putexcel B3="PCA Proxies" 
putexcel C3="Non-PCA Proxies"
putexcel D3="PCA Proxies" 
putexcel E3="Non-PCA Proxies"
putexcel F3="PCA Proxies" 
putexcel G3="Non-PCA Proxies"
putexcel A3:G3, border(bottom)
putexcel A4="Total Bias"
putexcel A6="Bias from Factor Loadings"
putexcel A8="Bias from Proxies"
putexcel A10="    Bias from Cognitive Factor"
putexcel A12="    Bias from Non-Cognitive Factor 1"
putexcel A14="    Bias from Non-Cognitive Factor 2"
putexcel A16="    Bias from Non-Cognitive Factor 3"
putexcel A18="    Bias from ASVAB General Science"
putexcel A20="    Bias from ASVAB Arithmetic Reasoning" 
putexcel A22="    Bias from ASVAB Mathematical Knowledge"
putexcel A24="    Bias from ASVAB Paragraph Comprehension"
putexcel A26="    Bias from ASVAB Word Knowledge"
putexcel A28="    Bias from ASVAB Coding Speed"
putexcel A30="    Bias from ASVAB Numeric Operations"
putexcel A32="    Bias from ASVAB Auto and Shop Information"
putexcel A34="    Bias from ASVAB Electronic Information"
putexcel A36="    Bias from ASVAB Mechanical Knowledge"
putexcel A38="    Bias from Rotter Scale"
putexcel A40="    Bias from Rosenberg Scale"
putexcel A41:G41, border(bottom)


***** IFE *****
* PCA PROXY VERSION

* FIRST, MERGE COMMON COMPONENT FROM MATLAB BACK INTO STATA
*import common component
import delimited "../mydata/common_ife_`m'wP.csv", varnames(nonames) encoding(Big5) clear 
forvalues i=1/25 {
	rename v`i' common`i'
}
save ${mydatapath}/common_ife_`m'wP.dta, replace

*get the caseid_1979 list the corresponds to the common component
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep log_HourlyWage1_cpi year caseid_1979
reshape wide log_HourlyWage1_cpi, i(caseid_1979) j(year)
keep caseid_1979
save ${mydatapath}/caseid_1979_list.dta, replace


*merge the common component onto ID list
merge 1:1 _n using ${mydatapath}/common_ife_`m'wP.dta
drop _merge
reshape long common, i(caseid_1979) j(year)
replace year=year+1980
replace year=year+1*(year-1994) if year>1994
save ${mydatapath}/common_ife_`m'wP_matched.dta, replace

*finally, merge common component back to the full doa
use ${mydatapath}/NLSYrep_doa.dta, clear
merge 1:1 caseid_1979 year using ${mydatapath}/common_ife_`m'wP_matched.dta, gen(_mergeCommon)


* RUN REGRESSIONS
* PCA proxies version
drop factor_c factor_n1 factor_n2 factor_n3
rename (factor_c_minti15 factor_n1_minti15 factor_n2_minti15 factor_n3_minti15) (factor_c factor_n1 factor_n2 factor_n3)

gen Y_defac=log_HourlyWage1_cpi-common

sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


*no proxies, no demos
xtreg log_HourlyWage1_cpi `spec' if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local ols=r(estimate)

*full model
xtreg Y_defac `spec' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local full=r(estimate)

local total_bias=`ols'-`full'
putexcel B4=`total_bias', nformat("#.####")

gen proxy_comp_total=.
forvalues y=1981/1994 {
	replace proxy_comp_total=_b[`y'.year#c.factor_c]*factor_c +_b[`y'.year#c.factor_n1]*factor_n1 +_b[`y'.year#c.factor_n2]*factor_n2 +_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_total=_b[`y'.year#c.factor_c]*factor_c +_b[`y'.year#c.factor_n1]*factor_n1 +_b[`y'.year#c.factor_n2]*factor_n2 +_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}

gen proxy_comp_c=.
forvalues y=1981/1994 {
	replace proxy_comp_c=_b[`y'.year#c.factor_c]*factor_c if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_c=_b[`y'.year#c.factor_c]*factor_c if year==`y' & `sample'==1
}

gen proxy_comp_n1=.
forvalues y=1981/1994 {
	replace proxy_comp_n1=_b[`y'.year#c.factor_n1]*factor_n1 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n1=_b[`y'.year#c.factor_n1]*factor_n1 if year==`y' & `sample'==1
}

gen proxy_comp_n2=.
forvalues y=1981/1994 {
	replace proxy_comp_n2=_b[`y'.year#c.factor_n2]*factor_n2 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n2=_b[`y'.year#c.factor_n2]*factor_n2 if year==`y' & `sample'==1
}

gen proxy_comp_n3=.
forvalues y=1981/1994 {
	replace proxy_comp_n3=_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n3=_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}


sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


xtreg common `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel B6=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_total `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel B8=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_c `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel B10=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_n1 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel B12=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_n2 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 

putexcel B14=(r(estimate)) , nformat("#.####")
xtreg proxy_comp_n3 `spec' if `sample', fe

lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel B16=(r(estimate)) , nformat("#.####")
	
	
	

	
* non-PCA PROXY VERSION
* FIRST, MERGE COMMON COMPONENT FROM MATLAB BACK INTO STATA
*import common component
import delimited "../mydata/common_ife_`m'wPalt.csv", varnames(nonames) encoding(Big5) clear 
forvalues i=1/25 {
	rename v`i' common`i'
}
save ${mydatapath}/common_ife_`m'wPalt.dta, replace

*get the caseid_1979 list the corresponds to the common component
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep log_HourlyWage1_cpi year caseid_1979
reshape wide log_HourlyWage1_cpi, i(caseid_1979) j(year)
keep caseid_1979
save ${mydatapath}/caseid_1979_list.dta, replace

*merge the common component onto ID list
merge 1:1 _n using ${mydatapath}/common_ife_`m'wPalt.dta
drop _merge
reshape long common, i(caseid_1979) j(year)
replace year=year+1980
replace year=year+1*(year-1994) if year>1994
save ${mydatapath}/common_ife_`m'wPalt_matched.dta, replace

*finally, merge common component back to the full doa
use ${mydatapath}/NLSYrep_doa.dta, clear
merge 1:1 caseid_1979 year using ${mydatapath}/common_ife_`m'wPalt_matched.dta, gen(_mergeCommon)


* RUN REGRESSIONS
* PCA proxies version
gen Y_defac=log_HourlyWage1_cpi-common

sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


*no proxies, no demos
xtreg log_HourlyWage1_cpi `spec' if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local ols=r(estimate)

*full model
xtreg Y_defac `spec' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local full=r(estimate)

local total_bias=`ols'-`full'
putexcel C4=`total_bias' , nformat("#.####")

gen proxy_comp_total=.
forvalues y=1981/1994 {
	replace proxy_comp_total=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std + _b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std + _b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std + _b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std + _b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std + _b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std + _b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std + _b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std + _b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std + _b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std + _b[`y'.year#c.rott_std]*rott_std + _b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_total=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std + _b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std + _b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std + _b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std + _b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std + _b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std + _b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std + _b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std + _b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std + _b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std + _b[`y'.year#c.rott_std]*rott_std + _b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab3=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab3=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab3=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab4=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab4=_b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab4=_b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab5=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab5=_b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab5=_b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab6=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab6=_b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab6=_b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab7=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab7=_b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab7=_b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab8=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab8=_b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab8=_b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab9=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab9=_b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab9=_b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab10=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab10=_b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab10=_b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab11=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab11=_b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab11=_b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab12=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab12=_b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab12=_b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_rott=.
forvalues y=1981/1994 {
	replace proxy_comp_rott=_b[`y'.year#c.rott_std]*rott_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_rott=_b[`y'.year#c.rott_std]*rott_std if year==`y' & `sample'==1
}
gen proxy_comp_rosen=.
forvalues y=1981/1994 {
	replace proxy_comp_rosen=_b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_rosen=_b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}



sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)

xtreg common `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel C6=(r(estimate)), nformat("#.####") 

xtreg proxy_comp_total `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel C8=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab3 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel C18=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab4 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel C20=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab10 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel C22=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab6 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel C24=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab5 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel C26=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab8 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel C28=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab7 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel C30=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab9 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel C32=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab12 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel C34=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab11 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel C36=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_rott `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel C38=(r(estimate)), nformat("#.####") 

xtreg proxy_comp_rosen `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel C40=(r(estimate)) , nformat("#.####")

	




***** CCE *****
* PCA PROXY VERSION
* FIRST, MERGE COMMON COMPONENT FROM MATLAB BACK INTO STATA
*import common component
import delimited "../mydata/common_cce_`m'wP.csv", varnames(nonames) encoding(Big5) clear 
forvalues i=1/25 {
	rename v`i' common`i'
}
save ${mydatapath}/common_cce_`m'wP.dta, replace

*get the caseid_1979 list the corresponds to the common component
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep log_HourlyWage1_cpi year caseid_1979
reshape wide log_HourlyWage1_cpi, i(caseid_1979) j(year)
keep caseid_1979
save ${mydatapath}/caseid_1979_list.dta, replace

*merge the common component onto ID list
merge 1:1 _n using ${mydatapath}/common_cce_`m'wP.dta
drop _merge
reshape long common, i(caseid_1979) j(year)
replace year=year+1980
replace year=year+1*(year-1994) if year>1994
save ${mydatapath}/common_cce_`m'wP_matched.dta, replace

*finally, merge common component back to the full doa
use ${mydatapath}/NLSYrep_doa.dta, clear
merge 1:1 caseid_1979 year using ${mydatapath}/common_cce_`m'wP_matched.dta, gen(_mergeCommon)


* RUN REGRESSIONS
* PCA proxies version
drop factor_c factor_n1 factor_n2 factor_n3
rename (factor_c_minti15 factor_n1_minti15 factor_n2_minti15 factor_n3_minti15) (factor_c factor_n1 factor_n2 factor_n3)

gen Y_defac=log_HourlyWage1_cpi-common

sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


*no proxies, no demos
xtreg log_HourlyWage1_cpi `spec' if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local ols=r(estimate)

*full model
xtreg Y_defac `spec' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local full=r(estimate)

local total_bias=`ols'-`full'
putexcel D4=`total_bias', nformat("#.####")

gen proxy_comp_total=.
forvalues y=1981/1994 {
	replace proxy_comp_total=_b[`y'.year#c.factor_c]*factor_c +_b[`y'.year#c.factor_n1]*factor_n1 +_b[`y'.year#c.factor_n2]*factor_n2 +_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_total=_b[`y'.year#c.factor_c]*factor_c +_b[`y'.year#c.factor_n1]*factor_n1 +_b[`y'.year#c.factor_n2]*factor_n2 +_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}

gen proxy_comp_c=.
forvalues y=1981/1994 {
	replace proxy_comp_c=_b[`y'.year#c.factor_c]*factor_c if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_c=_b[`y'.year#c.factor_c]*factor_c if year==`y' & `sample'==1
}

gen proxy_comp_n1=.
forvalues y=1981/1994 {
	replace proxy_comp_n1=_b[`y'.year#c.factor_n1]*factor_n1 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n1=_b[`y'.year#c.factor_n1]*factor_n1 if year==`y' & `sample'==1
}

gen proxy_comp_n2=.
forvalues y=1981/1994 {
	replace proxy_comp_n2=_b[`y'.year#c.factor_n2]*factor_n2 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n2=_b[`y'.year#c.factor_n2]*factor_n2 if year==`y' & `sample'==1
}

gen proxy_comp_n3=.
forvalues y=1981/1994 {
	replace proxy_comp_n3=_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n3=_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}



sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


xtreg common `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel D6=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_total `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel D8=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_c `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel D10=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_n1 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel D12=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_n2 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel D14=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_n3 `spec' if `sample', fe

lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel D16=(r(estimate)) , nformat("#.####")

	
	

	
* non-PCA PROXY VERSION
* FIRST, MERGE COMMON COMPONENT FROM MATLAB BACK INTO STATA
*import common component
import delimited "../mydata/common_cce_`m'wPalt.csv", varnames(nonames) encoding(Big5) clear 
forvalues i=1/25 {
	rename v`i' common`i'
}
save ${mydatapath}/common_cce_`m'wPalt.dta, replace

*get the caseid_1979 list the corresponds to the common component
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep log_HourlyWage1_cpi year caseid_1979
reshape wide log_HourlyWage1_cpi, i(caseid_1979) j(year)
keep caseid_1979
save ${mydatapath}/caseid_1979_list.dta, replace

*merge the common component onto ID list
merge 1:1 _n using ${mydatapath}/common_cce_`m'wPalt.dta
drop _merge
reshape long common, i(caseid_1979) j(year)
replace year=year+1980
replace year=year+1*(year-1994) if year>1994
save ${mydatapath}/common_cce_`m'wPalt_matched.dta, replace

*finally, merge common component back to the full doa
use ${mydatapath}/NLSYrep_doa.dta, clear
merge 1:1 caseid_1979 year using ${mydatapath}/common_cce_`m'wPalt_matched.dta, gen(_mergeCommon)


* RUN REGRESSIONS
* PCA proxies version
gen Y_defac=log_HourlyWage1_cpi-common

sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


*no proxies, no demos
xtreg log_HourlyWage1_cpi `spec' if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local ols=r(estimate)

*full model
xtreg Y_defac `spec' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local full=r(estimate)

local total_bias=`ols'-`full'
putexcel E4=`total_bias' , nformat("#.####")

gen proxy_comp_total=.
forvalues y=1981/1994 {
	replace proxy_comp_total=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std + _b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std + _b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std + _b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std + _b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std + _b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std + _b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std + _b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std + _b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std + _b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std + _b[`y'.year#c.rott_std]*rott_std + _b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_total=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std + _b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std + _b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std + _b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std + _b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std + _b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std + _b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std + _b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std + _b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std + _b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std + _b[`y'.year#c.rott_std]*rott_std + _b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab3=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab3=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab3=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab4=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab4=_b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab4=_b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab5=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab5=_b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab5=_b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab6=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab6=_b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab6=_b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab7=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab7=_b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab7=_b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab8=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab8=_b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab8=_b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab9=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab9=_b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab9=_b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab10=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab10=_b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab10=_b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab11=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab11=_b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab11=_b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab12=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab12=_b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab12=_b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_rott=.
forvalues y=1981/1994 {
	replace proxy_comp_rott=_b[`y'.year#c.rott_std]*rott_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_rott=_b[`y'.year#c.rott_std]*rott_std if year==`y' & `sample'==1
}
gen proxy_comp_rosen=.
forvalues y=1981/1994 {
	replace proxy_comp_rosen=_b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_rosen=_b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}



sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)

xtreg common `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel E6=(r(estimate)), nformat("#.####") 

xtreg proxy_comp_total `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel E8=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab3 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel E18=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab4 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel E20=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab10 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel E22=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab6 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel E24=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab5 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel E26=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab8 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel E28=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab7 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel E30=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab9 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel E32=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab12 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel E34=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab11 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel E36=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_rott `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel E38=(r(estimate)), nformat("#.####") 

xtreg proxy_comp_rosen `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel E40=(r(estimate)) , nformat("#.####")






***** CCE2 *****
* PCA PROXY VERSION
* FIRST, MERGE COMMON COMPONENT FROM MATLAB BACK INTO STATA
*import common component
import delimited "../mydata/common_cce2_`m'wP.csv", varnames(nonames) encoding(Big5) clear 
forvalues i=1/25 {
	rename v`i' common`i'
}
save ${mydatapath}/common_cce2_`m'wP.dta, replace

*get the caseid_1979 list the corresponds to the common component
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep log_HourlyWage1_cpi year caseid_1979
reshape wide log_HourlyWage1_cpi, i(caseid_1979) j(year)
keep caseid_1979
save ${mydatapath}/caseid_1979_list.dta, replace

*merge the common component onto ID list
merge 1:1 _n using ${mydatapath}/common_cce2_`m'wP.dta
drop _merge
reshape long common, i(caseid_1979) j(year)
replace year=year+1980
replace year=year+1*(year-1994) if year>1994
save ${mydatapath}/common_cce2_`m'wP_matched.dta, replace

*finally, merge common component back to the full doa
use ${mydatapath}/NLSYrep_doa.dta, clear
merge 1:1 caseid_1979 year using ${mydatapath}/common_cce2_`m'wP_matched.dta, gen(_mergeCommon)



* RUN REGRESSIONS
* PCA proxies version
drop factor_c factor_n1 factor_n2 factor_n3
rename (factor_c_minti15 factor_n1_minti15 factor_n2_minti15 factor_n3_minti15) (factor_c factor_n1 factor_n2 factor_n3)

gen Y_defac=log_HourlyWage1_cpi-common

sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


*no proxies, no demos
xtreg log_HourlyWage1_cpi `spec' if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local ols=r(estimate)

*full model
xtreg Y_defac `spec' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local full=r(estimate)

local total_bias=`ols'-`full'
putexcel F4=`total_bias', nformat("#.####")

gen proxy_comp_total=.
forvalues y=1981/1994 {
	replace proxy_comp_total=_b[`y'.year#c.factor_c]*factor_c +_b[`y'.year#c.factor_n1]*factor_n1 +_b[`y'.year#c.factor_n2]*factor_n2 +_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_total=_b[`y'.year#c.factor_c]*factor_c +_b[`y'.year#c.factor_n1]*factor_n1 +_b[`y'.year#c.factor_n2]*factor_n2 +_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}

gen proxy_comp_c=.
forvalues y=1981/1994 {
	replace proxy_comp_c=_b[`y'.year#c.factor_c]*factor_c if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_c=_b[`y'.year#c.factor_c]*factor_c if year==`y' & `sample'==1
}

gen proxy_comp_n1=.
forvalues y=1981/1994 {
	replace proxy_comp_n1=_b[`y'.year#c.factor_n1]*factor_n1 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n1=_b[`y'.year#c.factor_n1]*factor_n1 if year==`y' & `sample'==1
}

gen proxy_comp_n2=.
forvalues y=1981/1994 {
	replace proxy_comp_n2=_b[`y'.year#c.factor_n2]*factor_n2 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n2=_b[`y'.year#c.factor_n2]*factor_n2 if year==`y' & `sample'==1
}

gen proxy_comp_n3=.
forvalues y=1981/1994 {
	replace proxy_comp_n3=_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_n3=_b[`y'.year#c.factor_n3]*factor_n3 if year==`y' & `sample'==1
}



sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


xtreg common `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel F6=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_total `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel F8=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_c `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel F10=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_n1 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel F12=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_n2 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel F14=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_n3 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel F16=(r(estimate)) , nformat("#.####")

	
	

	
	
** non-PCA PROXY VERSION
* FIRST, MERGE COMMON COMPONENT FROM MATLAB BACK INTO STATA
*import common component
import delimited "../mydata/common_cce2_`m'wPalt.csv", varnames(nonames) encoding(Big5) clear 
forvalues i=1/25 {
	rename v`i' common`i'
}
save ${mydatapath}/common_cce2_`m'wPalt.dta, replace

*get the caseid_1979 list the corresponds to the common component
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep log_HourlyWage1_cpi year caseid_1979
reshape wide log_HourlyWage1_cpi, i(caseid_1979) j(year)
keep caseid_1979
save ${mydatapath}/caseid_1979_list.dta, replace

*merge the common component onto ID list
merge 1:1 _n using ${mydatapath}/common_cce2_`m'wPalt.dta
drop _merge
reshape long common, i(caseid_1979) j(year)
replace year=year+1980
replace year=year+1*(year-1994) if year>1994
save ${mydatapath}/common_cce2_`m'wPalt_matched.dta, replace

*finally, merge common component back to the full doa
use ${mydatapath}/NLSYrep_doa.dta, clear
merge 1:1 caseid_1979 year using ${mydatapath}/common_cce2_`m'wPalt_matched.dta, gen(_mergeCommon)



* RUN REGRESSIONS
* PCA proxies version
gen Y_defac=log_HourlyWage1_cpi-common

sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)


*no proxies, no demos
xtreg log_HourlyWage1_cpi `spec' if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local ols=r(estimate)

*full model
xtreg Y_defac `spec' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year if `sample', fe cluster(caseid_1979)
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
local full=r(estimate)

local total_bias=`ols'-`full'
putexcel G4=`total_bias' , nformat("#.####")

gen proxy_comp_total=.
forvalues y=1981/1994 {
	replace proxy_comp_total=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std + _b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std + _b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std + _b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std + _b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std + _b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std + _b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std + _b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std + _b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std + _b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std + _b[`y'.year#c.rott_std]*rott_std + _b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_total=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std + _b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std + _b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std + _b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std + _b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std + _b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std + _b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std + _b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std + _b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std + _b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std + _b[`y'.year#c.rott_std]*rott_std + _b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab3=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab3=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab3=_b[`y'.year#c.asvab_3_1981_std]*asvab_3_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab4=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab4=_b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab4=_b[`y'.year#c.asvab_4_1981_std]*asvab_4_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab5=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab5=_b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab5=_b[`y'.year#c.asvab_5_1981_std]*asvab_5_1981_std if year==`y' & `sample'==1
}

gen proxy_comp_asvab6=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab6=_b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab6=_b[`y'.year#c.asvab_6_1981_std]*asvab_6_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab7=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab7=_b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab7=_b[`y'.year#c.asvab_7_1981_std]*asvab_7_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab8=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab8=_b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab8=_b[`y'.year#c.asvab_8_1981_std]*asvab_8_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab9=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab9=_b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab9=_b[`y'.year#c.asvab_9_1981_std]*asvab_9_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab10=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab10=_b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab10=_b[`y'.year#c.asvab_10_1981_std]*asvab_10_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab11=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab11=_b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab11=_b[`y'.year#c.asvab_11_1981_std]*asvab_11_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_asvab12=.
forvalues y=1981/1994 {
	replace proxy_comp_asvab12=_b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_asvab12=_b[`y'.year#c.asvab_12_1981_std]*asvab_12_1981_std if year==`y' & `sample'==1
}
gen proxy_comp_rott=.
forvalues y=1981/1994 {
	replace proxy_comp_rott=_b[`y'.year#c.rott_std]*rott_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_rott=_b[`y'.year#c.rott_std]*rott_std if year==`y' & `sample'==1
}
gen proxy_comp_rosen=.
forvalues y=1981/1994 {
	replace proxy_comp_rosen=_b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}
forvalues y=1996(2)2016 {
	replace proxy_comp_rosen=_b[`y'.year#c.rosen_std]*rosen_std if year==`y' & `sample'==1
}



sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)

xtreg common `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel G6=(r(estimate)), nformat("#.####") 

xtreg proxy_comp_total `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel G8=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab3 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel G18=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab4 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel G20=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab10 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel G22=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab6 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel G24=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab5 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel G26=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab8 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel G28=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab7 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel G30=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab9 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel G32=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab12 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel G34=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_asvab11 `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel G36=(r(estimate)) , nformat("#.####")

xtreg proxy_comp_rott `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel G38=(r(estimate)), nformat("#.####") 

xtreg proxy_comp_rosen `spec' if `sample', fe
lincom _b[Education]+2*_b[Education2]*`educyears_mean'+_b[EducAge]*`age_mean' 
putexcel G40=(r(estimate)) , nformat("#.####")



}

log close

