%Separate program for performing IFE bootstrap for Kejriwal, Li, and Totty (2021)

function [betaIFE1breps,YstarIFEbreps,betaCCEPIFEbreps,nnnIFEbreps,nEMIFEbreps,FIFEbreps,LIFEbreps]=IFEbc_se_bootstrap(betaIFE0,X1,Y1,xxinv,U_defac1,F1,L1,rmax,rfix,order,S, demean, Xorig,nonmiss,mgfe,knum,Zw);
[T,N,p]=size(X1);
Ti=sum(nonmiss,1);


%% STARTING METHOD 1
breps=400;
betaIFE1breps=zeros(p,breps);
YstarIFEbreps=zeros(T,N,breps);
betaCCEPIFEbreps=zeros(p,breps);
nnnIFEbreps=zeros(1,breps);
nEMIFEbreps=zeros(1,breps);
FIFEbreps=zeros(T,rmax,breps);
LIFEbreps=zeros(N,rmax,breps);
% FIRST, GENERATE CONSTANT PARTS OF BOOSTRAP REPS
if demean==2
    Ybar_i=nanmean(Y1,1);
    Xbar_i=zeros(p,N);
    for j=1:p
        Xbar_i(j,:)=nanmean(X1(:,:,j),1);
    end
    alpha_hat=Ybar_i'-Xbar_i'*betaIFE0(:,1);
end

y_star=ones(T,1)*alpha_hat';
for j=1:p
    y_star=y_star+X1(:,:,j)*betaIFE0(j,1);
end
y_star=y_star+F1*L1';


% NOW, LOOP THROUGH OUTER-LOOP BOOTSTRAP REPS, GENERATE DATA, AND ESTIMATE COEFS
sc=parallel.pool.Constant(RandStream('mrg32k3a'))
w=zeros(breps,N);
parfor b=1:breps
    stream=sc.Value;
    stream.Substream=b;
    b
    Xdot=zeros(T,N,p);
    Ydot=zeros(T,N);
    Xcsavgs=zeros(T,N,p);
    Ycsavgs=zeros(T,N);
    r1b=0;
    w(b,:)=randn(stream,1,N);
    W=repmat(w(b,:),T,1);
    U_star=U_defac1.*W;
    Y_star=y_star+U_star;
    
    
    % remove state-specific trends and demean for X,Y in estimation
    [Xdet,Ydet] = RemoveTimeTrends(X1,Y_star,order,S);
    if demean==0
        Xdot=Xdet;
        Ydot=Ydet;
    elseif demean==1
        [Xdot,Ydot]=CSDemean_unbalanced(Xdet,Ydet,1);
    elseif demean==2
        [Xdot,Ydot]=TimeDemean_unbalanced(Xdet,Ydet,1);
    elseif demean==3
        [Xdot,Ydot]=DemeanData_unbalanced(Xdet,Ydet);
    end
    X=Xdot;
    Y=Ydot;
    
    
    % Estimation
    % Starting method 1:

    % Prepare data used for cross-section averages; not necessarily the
    % same as above because above may have partialled out time-related 
    % effects (e.g., demo-by-year) or have regular time fixed effects, in
    % which case the cross-section averages are ~0. Person fixed effects
    % are handled here, but could alternatively be handled via a Tx1 vector
    % of ones in the Zw matrix below.
    if mgfe==1
        [Xcsavgs,Ycsavgs]=TimeDemean_unbalanced(Xorig,Y_star,1);
    elseif mgfe==0
        Xcsavgs=Xorig;
        Ycsavgs=Y_star;
    end
    
    Zw=zeros(T,knum);
    Zw(:,1)=nanmean(Ycsavgs,2);
    for j=1:knum-1
        Zw(:,1+j)=nanmean(Xcsavgs(:,:,j),2);
    end;
    
     XX=zeros(p,p,N);
     XY=zeros(p,1,N);
     for i=1:N
         Xi=zeros(Ti(1,i),p);
         for j=1:p
             xij=X(:,i,j);
             Xi(:,j)=xij(~isnan(xij));
         end;
         Yi=Y(:,i);
         Yi=Yi(~isnan(Yi));
         
         Zwi=zeros(Ti(1,i),knum);
         zwi1=Zw(:,1);
         Zwi(:,1)=zwi1(~isnan(Yi));
         for j=1:knum-1
             zwij=Zw(:,1+j);
             Zwi(:,1+j)=zwij(~isnan(Yi));
         end;
         Hwi=Zwi;
         Mi=eye(Ti(1,i)) - Hwi*((Hwi'*Hwi)\Hwi');
         
         XX(:,:,i)=(1/N)*(Xi'*Mi*Xi);
         XY(:,:,i)=(1/N)*(Xi'*Mi*Yi);
     end;
     XXsum=sum(XX,3);
     XYsum=sum(XY,3);
     betaCCEp_boot=XXsum\XYsum;
    
    
    % estimate factors from CCE residuals
    U_boot=Y;
    for j=1:p;
        U_boot=U_boot-X(:,:,j)* betaCCEp_boot(j,1);
    end
    
    li=zeros(knum,N);
    for i=1:N;
        Ui=U_boot(:,i);

        Zwi=zeros(Ti(1,i),knum);
        zwi1=Zw(:,1);
        Zwi(:,1)=zwi1(~isnan(Ui));
        for j=1:knum-1;
            zwij=Zw(:,1+j);
            Zwi(:,1+j)=zwij(~isnan(Ui));
        end;
        Hwi=[Zwi];

        Ui=Ui(~isnan(Ui));
        
    Hwi_mean=mean(Hwi,1);
    Hwi_d=Hwi-ones(Ti(1,i),1)*Hwi_mean;
        
        li(:,i)=(Hwi'*Hwi)\(Hwi'*Ui);
    end;
    F1b=[Zw];
    L1b=li';

    % Estimation
    % Pooled Estimator
   if rfix==0
       [r1b,~,~,~]=nbplog(U,rmax,1,0);
   elseif rfix==1
       r1b=rmax;
   end
    
    % Perform IFE iteration
    [betaIFE1breps(:,b), F1b,L1b, VNT1b, e1b, nnnb,r1b,nEMb]=Mul_betaIterNew_unbalanced(X, Y, xxinv, U_boot,F1b,L1b, r1b,rmax,rfix, 0.005,nonmiss);
    
    
YstarIFEbreps(:,:,b)=Y_star;
betaCCEPIFEbreps(:,b)=betaCCEp_boot;
nnnIFEbreps(:,b)=nnnb;
nEMIFEbreps(:,b)=nEMb;   
FIFEbreps(:,:,b)=F1b;
LIFEbreps(:,:,b)=L1b;
end




