%Inputs:
%	1. P: Nxm matrix of proxies
%	2. L: Nxr matrix of factor loadings
%	3. Lboot: NxrxB matrix of bootstrap factor loadings

%Outputs:
%	1. A: 1xm vector reporting % of N with statistically significant t-stat test
%	2. R2: 1xm vector of coefficient of determination statistics
%	3. R2_lower: lower 95% CI for R2
%	4. R2_upper: upper 95% CI for R2
%	5. C: 1xr vector of canonical correlations
%	6. C_lower: lower 95% CI for C
%	7. C_upper: upper 95% CI for C


function [A,R2,R2_lower,R2_upper,C,C_lower,C_upper] = proxy_tests(P,L,Lboot);

[N,m]=size(P);
[N,r,breps]=size(Lboot);


%T-statistic test
Lcovar=zeros(r,r,N);
for i=1:N
    input=Lboot(i,:,:);
    input=permute(input,[3,2,1]);
    Lcovar(:,:,i)=cov(input);
end

upvarphi=zeros(r,m);
P_hat=zeros(N,m);
tstats=zeros(N,m);
sigstat=zeros(N,m);
for j=1:m
    upvarphi(:,j)=(L'*L)\(L'*P(:,j));
    P_hat(:,j)=upvarphi(:,j)'*L';
    for i=1:N
        vari=upvarphi(:,j)'*Lcovar(:,:,i)*upvarphi(:,j);
        tstats(i,j)=(P_hat(i,j)-P(i,j))/sqrt(vari);
	if abs(tstats(i,j))>1.96
	    sigstat(i,j)=1;
        end
    end
end


A=mean(sigstat,1);



%Coefficient of Determination test
R2=zeros(1,m);
R=zeros(1,m);
R2_lower=zeros(1,m);
R2_upper=zeros(1,m);
for j=1:m
    R2(1,j)=(P_hat(:,j)'*P_hat(:,j))/(P(:,j)'*P(:,j));
    R(1,j)=sqrt(R2(1,j));
    R2_lower(1,j)=R2(1,j)-2*1.96*(R(1,j)*(1-R2(1,j)))/sqrt(N);
    R2_upper(1,j)=R2(1,j)+2*1.96*(R(1,j)*(1-R2(1,j)))/sqrt(N);
end



%Canonical Correlations test
s00=L'*L/N;
s11=P'*P/N;
s10=P'*L/N;
sigma=inv(s11)*s10*inv(s00)*s10';
%[~,eigval,~]=svd(sigma);
%C=diag(eigval)';
s=eig(sigma);
s=sort(s,1);
C=flipud(s);
C=C';
C_lower=zeros(1,r);
C_upper=zeros(1,r);
for k=1:r
    C_lower(1,k)=C(1,k)-1.96*2*(sqrt(C(1,k))*(1-C(1,k)))/sqrt(N);
    C_upper(1,k)=C(1,k)+1.96*2*(sqrt(C(1,k))*(1-C(1,k)))/sqrt(N);
end





