/*
This program performs the OLS and FM estimation. There are 
several different specifications and samples considered in 
the paper. Each sample/specification has its own estimation 
program. This program calls each of those programs.

Each regressions_{name}.do program performs the OLS estimation 
for the given sample/specification, exports the data for factor 
model estimation in Matlab, and then uses the "shell" command 
to call the Matlab program that performs the factor model estimation. 
They also save the OLS results into spreadsheets in the ../output/
folder named returns_{name}.xlsx.

This program also calls regressions_fmtables.m that outputs the FM estimation 
results into spreadsheets in ../output/ named "returns_{name}_fm.csv. 
The CSVs have the same format as the tables in the paper and 
the .xlsx file of OLS results, but these CSVs only fill in the 
cells associated with FM results. 

A user can estimate all of the samples/specifications at once 
or comment out some samples/specifications. If any of the 
regressions_{name}.do programs are commented out, the portion 
of the regressions_fmtables.m program that prepares the FM CSVs
for that sample/specification also needs to be commented out.
*/

global dopath "./"

*main sample from the paper
do ${dopath}/regressions_minti15.do

*alternative robustness samples
do ${dopath}/regressions_agequartic.do
do ${dopath}/regressions_linear.do
do ${dopath}/regressions_altfull.do
do ${dopath}/regressions_altwh.do
do ${dopath}/regressions_altb.do

*output FM results
do ${dopath}/regressions_exportpartial.do
shell /apps/matlab/R2016a/bin/matlab -nosplash -nodisplay -nodesktop -r "try; run('regressions_fmtables.m'); catch ME; disp(ME); end; quit" > regressions_fmtables.log


