/*
This program partials out any fixed effects from the dependent 
variable so that proper r-squared results for the factor models 
can be computed in Matlab. The partialled out dependent variable
is then exported for use in a later Matlab program.
*/


global mydatapath "../mydata"
global outputpath "../output"


log using ${dopath}/regressions_exportpartial.log, replace


*** main (minTi=15) sample
local sample insample_minti15

*Export X data to use for estimation
local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	drop factor_c factor_n1 factor_n2 factor_n3
	rename (factor_c_minti15 factor_n1_minti15 factor_n2_minti15 factor_n3_minti15) (factor_c factor_n1 factor_n2 factor_n3)
	xtreg `var' if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_minti15.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	drop factor_c factor_n1 factor_n2 factor_n3
	rename (factor_c_minti15 factor_n1_minti15 factor_n2_minti15 factor_n3_minti15) (factor_c factor_n1 factor_n2 factor_n3)
	xtreg `var' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wP_minti15.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wPalt_minti15.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wD_minti15.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	drop factor_c factor_n1 factor_n2 factor_n3
	rename (factor_c_minti15 factor_n1_minti15 factor_n2_minti15 factor_n3_minti15) (factor_c factor_n1 factor_n2 factor_n3)
	xtreg `var' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wPwD_minti15.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wPaltwD_minti15.xls, sheetreplace
}



*** altfull sample
local sample insample

*Export X data to use for estimation
local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_altfull.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wP_altfull.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wPalt_altfull.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wD_altfull.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wPwD_altfull.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wPaltwD_altfull.xls, sheetreplace
}




*** altb sample
local sample insample_altb

*Export X data to use for estimation
local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	drop factor_c factor_n1 factor_n2 factor_n3
	rename (factor_c_altb factor_n1_altb factor_n2_altb factor_n3_altb) (factor_c factor_n1 factor_n2 factor_n3)
	xtreg `var' if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_altb.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	drop factor_c factor_n1 factor_n2 factor_n3
	rename (factor_c_altb factor_n1_altb factor_n2_altb factor_n3_altb) (factor_c factor_n1 factor_n2 factor_n3)
	xtreg `var' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wP_altb.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wPalt_altb.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wD_altb.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	drop factor_c factor_n1 factor_n2 factor_n3
	rename (factor_c_altb factor_n1_altb factor_n2_altb factor_n3_altb) (factor_c factor_n1 factor_n2 factor_n3)
	xtreg `var' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wPwD_altb.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wPaltwD_altb.xls, sheetreplace
}





*** altwh sample
local sample insample_altwh

*Export X data to use for estimation
local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	drop factor_c factor_n1 factor_n2 factor_n3
	rename (factor_c_altwh factor_n1_altwh factor_n2_altwh factor_n3_altwh) (factor_c factor_n1 factor_n2 factor_n3)
	xtreg `var' if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_altwh.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	drop factor_c factor_n1 factor_n2 factor_n3
	rename (factor_c_altwh factor_n1_altwh factor_n2_altwh factor_n3_altwh) (factor_c factor_n1 factor_n2 factor_n3)
	xtreg `var' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wP_altwh.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wPalt_altwh.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wD_altwh.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	drop factor_c factor_n1 factor_n2 factor_n3
	rename (factor_c_altwh factor_n1_altwh factor_n2_altwh factor_n3_altwh) (factor_c factor_n1 factor_n2 factor_n3)
	xtreg `var' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wPwD_altwh.xls, sheetreplace
}


local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year if `sample'==1, fe
	predict `var'_res, xbu
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSYyres_wPaltwD_altwh.xls, sheetreplace
}




log close
