/*
This program runs the OLS and FM regressions. 
OLS regressions are run directly in Stata.
FM regressions are run in Matlab through Stata 
	by using the "shell" command.
	
There are four different specifications:
1. No proxies, no demographics
2. Proxy-by-year FE, no demographics3
3. No proxies, demo-by-year FE
4. Proxy-by-year FE, demo-by-year FE

Proxies use the cognitive and non-cognitive 
	PCA factors created in the "p2" 
	program.
*/

global mydatapath "../mydata"
global outputpath "../output"


use ${mydatapath}/NLSYrep_doa.dta, clear
log using ./regressions_linear.log, replace



local sample insample_minti15
local spec Education Age Age2
drop factor_c factor_n1 factor_n2 factor_n3
rename (factor_c_minti15 factor_n1_minti15 factor_n2_minti15 factor_n3_minti15) (factor_c factor_n1 factor_n2 factor_n3)

*** PREP OUTPUT TABLE
putexcel set ../output/returns_linear.xlsx, sheet(table) replace
putexcel A1:M1, border(bottom)
putexcel B2:D2="OLS"
putexcel E2:G2="IFE"
putexcel H2:J2="CCE"
putexcel K2:M2="CCE-2"
putexcel A2:M2, border(bottom)
putexcel A3="Without demographic controls"
putexcel A4="Marginal return"
putexcel A7="Demos-by-year FE" B7:M7="No"
putexcel A8="PCA Proxies-by-year FE" B8="No" C8="Yes" D8="No" E8="No" F8="Yes" G8="No" H8="No" I8="Yes" J8="No" K8="No" L8="Yes" M8="No"
putexcel A9="Non-PCA Proxies-by-year FE" B9:C9="No" D9="Yes" E9:F9="No" G9="Yes" H9:I9="No" J9="Yes" K9:L9="No" M9="Yes"
putexcel A10="Adjusted R-squared"
putexcel A11="Alt marginal return"
putexcel A12="CD statistic"
putexcel A12:M12, border(bottom)
putexcel A13="With demographic controls"
putexcel A14="Marginal return"
putexcel A17="Demos-by-year FE" B17:M17="Yes"
putexcel A18="PCA Proxies-by-year FE" B18="No" C18="Yes" D18="No" E18="No" F18="Yes" G18="No" H18="No" I18="Yes" J18="No" K18="No" L18="Yes" M18="No"
putexcel A19="Non-PCA Proxies-by-year FE" B19:C19="No" D19="Yes" E19:F19="No" G19="Yes" H19:I19="No" J19="Yes" K19:L19="No" M19="Yes"
putexcel A20="Adjusted R-squared"
putexcel A21="Alt marginal return"
putexcel A22="CD statistic"
putexcel A22:M22, border(bottom)


*** RUN OLS REGRESSIONS

sum Education if `sample'==1
local educyears_mean=r(mean)

sum Age if `sample'==1
local age_mean=r(mean)

*no proxies, no demos
xtreg log_HourlyWage1_cpi `spec' if `sample', fe cluster(caseid_1979)
putexcel B4=_b[Education]
putexcel B5=_se[Education]
local r2_w=e(r2_w)
putexcel B10=`r2_w'

*proxies1, no demos
xtreg log_HourlyWage1_cpi `spec' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year if `sample', fe cluster(caseid_1979)
putexcel C4=_b[Education]
putexcel C5=_se[Education]
local r2_w=e(r2_w)
putexcel C10=`r2_w'

*proxies2, no demos
xtreg log_HourlyWage1_cpi `spec' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year if `sample', fe cluster(caseid_1979)
putexcel D4=_b[Education]
putexcel D5=_se[Education]
local r2_w=e(r2_w)
putexcel D10=`r2_w'

*no proxies, demos
xtreg log_HourlyWage1_cpi `spec' c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year if `sample', fe cluster(caseid_1979)
putexcel B14=_b[Education]
putexcel B15=_se[Education]
local r2_w=e(r2_w)
putexcel B20=`r2_w'

*proxies1, demos
xtreg log_HourlyWage1_cpi `spec' c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year if `sample', fe cluster(caseid_1979)
putexcel C14=_b[Education]
putexcel C15=_se[Education]
local r2_w=e(r2_w)
putexcel C20=`r2_w'

*proxies2, demos
xtreg log_HourlyWage1_cpi `spec' c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year if `sample', fe cluster(caseid_1979)
putexcel D14=_b[Education]
putexcel D15=_se[Education]
local r2_w=e(r2_w)
putexcel D20=`r2_w'




*** NOW OUTPUT DATA TO EXCEL AND RUN FM REGRESSIONS IN MATLAB
******************************
* 1. Without proxies, without demos
******************************
*Export outcome data for estimationvar
local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	keep if `sample'==1 
	keep `var' year caseid_1979
	reshape wide `var', i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'.xls, sheetreplace
}
*Export X data to use for estimation
foreach var in `spec' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	keep if `sample'==1 
	label values `var'
	keep `var' year caseid_1979
	reshape wide `var', i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'.xls, sheetreplace
}
*Export original X data for margin returns and cross-section averages
foreach var in `spec' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	keep if `sample'==1 
	label values `var'
	keep `var' year caseid_1979
	reshape wide `var', i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'_orig.xls, sheetreplace
}
*Export a matrix of missing indicators
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep Age2 year caseid_1979
reshape wide Age2, i(caseid_1979) j(year)
drop caseid_1979
foreach var of varlist _all {
	replace `var'=1 if !missing(`var')
	replace `var'=0 if missing(`var')
}
export excel using ${mydatapath}/NonmissingObs.xls, sheetreplace


* Estimate factor models
shell /apps/matlab/R2016a/bin/matlab -nosplash -nodisplay -nodesktop -r "try; run('FMestimation_saa2_iFE_unbal.m'); catch ME; disp(ME); end; quit" > FMestimation_saa2_iFE_unbal.log
shell mv "../mydata/Results_saa2_iFE_unbal.mat" "../mydata/Results_saa2_minti15.mat"







******************************
* 2. With proxies - PCA
******************************
*Export outcome data for estimation
local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	keep if `sample'==1 
	keep `var' year caseid_1979
	reshape wide `var', i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'.xls, sheetreplace
}
*Export X data to use for estimation
foreach var in `spec' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	drop factor_c factor_n1 factor_n2 factor_n3
	rename (factor_c_minti15 factor_n1_minti15 factor_n2_minti15 factor_n3_minti15) (factor_c factor_n1 factor_n2 factor_n3)
	xtreg `var' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year if `sample'==1, fe
	predict `var'_res, e
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'.xls, sheetreplace
}
*Export original X data for margin returns and cross-section averages
foreach var in `spec' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	keep if `sample'==1 
	label values `var'
	keep `var' year caseid_1979
	reshape wide `var', i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'_orig.xls, sheetreplace
}
*Export a matrix of missing indicators
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep Age2 year caseid_1979
reshape wide Age2, i(caseid_1979) j(year)
drop caseid_1979
foreach var of varlist _all {
	replace `var'=1 if !missing(`var')
	replace `var'=0 if missing(`var')
}
export excel using ${mydatapath}/NonmissingObs.xls, sheetreplace


* Estimate factor models
shell /apps/matlab/R2016a/bin/matlab -nosplash -nodisplay -nodesktop -r "try; run('FMestimation_saa2_iFE_unbal.m'); catch ME; disp(ME); end; quit" > FMestimation_saa2_iFE_unbal.log
shell mv "../mydata/Results_saa2_iFE_unbal.mat" "../mydata/Results_saa2wP_minti15.mat"




******************************
* 3. With proxies - disaggregated
******************************
*Export outcome data for estimation
local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	keep if `sample'==1 
	keep `var' year caseid_1979
	reshape wide `var', i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'.xls, sheetreplace
}
*Export X data to use for estimation
foreach var in `spec' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year if `sample'==1, fe
	predict `var'_res, e
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'.xls, sheetreplace
}
*Export original X data for margin returns and cross-section averages
foreach var in `spec' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	keep if `sample'==1 
	label values `var'
	keep `var' year caseid_1979
	reshape wide `var', i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'_orig.xls, sheetreplace
}
*Export a matrix of missing indicators
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep Age2 year caseid_1979
reshape wide Age2, i(caseid_1979) j(year)
drop caseid_1979
foreach var of varlist _all {
	replace `var'=1 if !missing(`var')
	replace `var'=0 if missing(`var')
}
export excel using ${mydatapath}/NonmissingObs.xls, sheetreplace


* Estimate factor models
shell /apps/matlab/R2016a/bin/matlab -nosplash -nodisplay -nodesktop -r "try; run('FMestimation_saa2_iFE_unbal.m'); catch ME; disp(ME); end; quit" > FMestimation_saa2_iFE_unbal.log
shell mv "../mydata/Results_saa2_iFE_unbal.mat" "../mydata/Results_saa2wPalt_minti15.mat"






******************************
* 4. Without proxies, with demos
******************************
*Export outcome data for estimation
local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	keep if `sample'==1 
	keep `var' year caseid_1979
	reshape wide `var', i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'.xls, sheetreplace
}
*Export X data to use for estimation
foreach var in `spec' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year if `sample'==1, fe
	predict `var'_res, e
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'.xls, sheetreplace
}
*Export original X data for margin returns and cross-section averages
foreach var in `spec' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	keep if `sample'==1 
	label values `var'
	keep `var' year caseid_1979
	reshape wide `var', i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'_orig.xls, sheetreplace
}
*Export a matrix of missing indicators
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep Age2 year caseid_1979
reshape wide Age2, i(caseid_1979) j(year)
drop caseid_1979
foreach var of varlist _all {
	replace `var'=1 if !missing(`var')
	replace `var'=0 if missing(`var')
}
export excel using ${mydatapath}/NonmissingObs.xls, sheetreplace


* Estimate factor models
shell /apps/matlab/R2016a/bin/matlab -nosplash -nodisplay -nodesktop -r "try; run('FMestimation_saa2_iFE_unbal.m'); catch ME; disp(ME); end; quit" > FMestimation_saa2_iFE_unbal.log
shell mv "../mydata/Results_saa2_iFE_unbal.mat" "../mydata/Results_saa2wD_minti15.mat"







******************************
* 5. With proxies - PCA, with demos
******************************
*Export outcome data for estimation
local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	keep if `sample'==1 
	keep `var' year caseid_1979
	reshape wide `var', i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'.xls, sheetreplace
}
*Export X data to use for estimation
foreach var in `spec' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	drop factor_c factor_n1 factor_n2 factor_n3
	rename (factor_c_minti15 factor_n1_minti15 factor_n2_minti15 factor_n3_minti15) (factor_c factor_n1 factor_n2 factor_n3)
	xtreg `var' c.factor_c#i.year c.factor_n1#i.year c.factor_n2#i.year c.factor_n3#i.year c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year if `sample'==1, fe
	predict `var'_res, e
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'.xls, sheetreplace
}
*Export original X data for margin returns and cross-section averages
foreach var in `spec' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	keep if `sample'==1 
	label values `var'
	keep `var' year caseid_1979
	reshape wide `var', i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'_orig.xls, sheetreplace
}
*Export a matrix of missing indicators
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep Age2 year caseid_1979
reshape wide Age2, i(caseid_1979) j(year)
drop caseid_1979
foreach var of varlist _all {
	replace `var'=1 if !missing(`var')
	replace `var'=0 if missing(`var')
}
export excel using ${mydatapath}/NonmissingObs.xls, sheetreplace


* Estimate factor models
shell /apps/matlab/R2016a/bin/matlab -nosplash -nodisplay -nodesktop -r "try; run('FMestimation_saa2_iFE_unbal.m'); catch ME; disp(ME); end; quit" > FMestimation_saa2_iFE_unbal.log
shell mv "../mydata/Results_saa2_iFE_unbal.mat" "../mydata/Results_saa2wPwD_minti15.mat"





******************************
* 6. With proxies - disaggregated, with demos
******************************
*Export outcome data for estimation
local vars log_HourlyWage1_cpi
foreach var in `vars' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	keep if `sample'==1 
	keep `var' year caseid_1979
	reshape wide `var', i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'.xls, sheetreplace
}
*Export X data to use for estimation
foreach var in `spec' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	xtreg `var' c.asvab_3_1981_std#i.year c.asvab_4_1981_std#i.year c.asvab_5_1981_std#i.year c.asvab_6_1981_std#i.year c.asvab_7_1981_std#i.year c.asvab_8_1981_std#i.year c.asvab_9_1981_std#i.year c.asvab_10_1981_std#i.year c.asvab_11_1981_std#i.year c.asvab_12_1981_std#i.year c.rott_std#i.year c.rosen_std#i.year c.Sibling#i.year c.MotherEducation#i.year c.FatherEducation#i.year if `sample'==1, fe
	predict `var'_res, e
	keep if `sample'==1 
	label values `var'_res
	keep `var'_res year caseid_1979
	reshape wide `var'_res, i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'.xls, sheetreplace
}
*Export original X data for margin returns and cross-section averages
foreach var in `spec' {
	use ${mydatapath}/NLSYrep_doa.dta, clear
	keep if `sample'==1 
	label values `var'
	keep `var' year caseid_1979
	reshape wide `var', i(caseid_1979) j(year)
	drop caseid_1979
	export excel using ${mydatapath}/NLSY`var'_orig.xls, sheetreplace
}
*Export a matrix of missing indicators
use ${mydatapath}/NLSYrep_doa.dta, clear
keep if `sample'==1 
keep Age2 year caseid_1979
reshape wide Age2, i(caseid_1979) j(year)
drop caseid_1979
foreach var of varlist _all {
	replace `var'=1 if !missing(`var')
	replace `var'=0 if missing(`var')
}
export excel using ${mydatapath}/NonmissingObs.xls, sheetreplace


* Estimate factor models
shell /apps/matlab/R2016a/bin/matlab -nosplash -nodisplay -nodesktop -r "try; run('FMestimation_saa2_iFE_unbal.m'); catch ME; disp(ME); end; quit" > FMestimation_saa2_iFE_unbal.log
shell mv "../mydata/Results_saa2_iFE_unbal.mat" "../mydata/Results_saa2wPaltwD_minti15.mat"



log close
